from enum import Enum

class LeicaReturnCode(Enum):
    GRC_OK = 0  # Execution successful.
    NOTHING_TO_READ = 1
    GRC_IVPARAM = 2  # Invalid parameter (e.g. no valid position).
    GRC_IVRESULT = 3  # RL EDM type is set – no reflector./ Wrong values entered.
    GRC_FATAL = 4  # Fatal error
    GRC_NOT_IMPL = 5  # Not implemented yet.
    GRC_SETINCOMPLETE = 7  # Invalid number of parameters.
    GRC_ABORT = 8  # Function aborted.
    GRC_SHUT_DOWN = 12  # Error
    GRC_SYSBUSY = 13  # EDM already busy
    GRC_LOW_POWER = 16  # Power is low. Time remaining is about 30 Minutes.
    GRC_BATT_EMPTY = 18  # Battery is nearly empty. Time remaining is about 1 Minute.
    GRC_NA = 27  # GeoCOM Robotic license key not available
    GRC_ATA_NO_TARGET = 517  # No target detected
    GRC_ATA_STRANGE_LIGHT = 524  # No target detected
    GRC_EDM_INVALID_COMMAND = 770  # When an invalid intensity is entered
    GRC_EDM_DEV_NOT_INSTALLED = 778  # Laserpointer is not implemented
    TMC_NO_FULL_CORRECTION = 1283  # Error with angle measurement
    TMC_ACCURACY_GUARANTEE = 1284  # Info
    TMC_ANGLE_OK = 1285  # Warning
    TMC_ANGLE_NO_FULL_CORRECTION = 1288  # Warning
    TMC_ANGLE_ACCURACY_GUARANTEE = 1289  # Info
    TMC_ANGLE_ERROR = 1290  # Error
    TMC_DIST_PPM = 1291  # Error
    TMC_DIST_ERROR = 1292  # An error occurred during distance measurement.
    TMC_BUSY = 1293  # Error
    TMC_SIGNAL_ERROR = 1294  # Error
    GRC_MOT_UNREADY = 1792  # No movement in progress (e.g. stop without start).
    GRC_MOT_NOT_OCONST = 1794  # Drive is not in mode MOT_OCONST
    GRC_MOT_NOT_CONFIG = 1795  # System is not in state MOT_CONFIG or MOT_BUSY_OPEN_END
    GRC_COM_CANT_ENCODE = 3073  # Can't encode arguments in client.
    GRC_COM_CANT_DECODE = 3074  # Can't decode results in client.
    GRC_COM_CANT_SEND = 3075  # Failure in sending calls.
    GRC_COM_CANT_RECV = 3076  # Failure in receiving result
    GRC_COM_TIMEDOUT = 3077  # Communication timeout.
    GRC_COM_WRONG_FORMAT = 3078  # The request and receive formats are different
    GRC_COM_VER_MISMATCH = 3079  # RPC protocol mismatch error
    GRC_COM_CANT_DECODE_REQ = 3080  # Can't decode request in server
    GRC_COM_PROC_UNAVAIL = 3081  # The requested procedure is unavailable in the server.
    GRC_COM_CANT_ENCODE_REP = 3082  # Can't encode reply in server.
    GRC_COM_SYSTEM_ERR = 3083  # Communication hardware error
    GRC_COM_FAILED = 3085  # Mess into communication itself
    GRC_COM_NO_BINARY = 3086  # Unknown protocol
    GRC_COM_INTR = 3087  # Call interrupted
    GRC_COM_REQUIRES_8DBITS = 3090  # This error indicates desired protocol requires 8 data bits
    GRC_COM_TR_ID_MISMATCH = 3093  # Request and reply transaction ids do not match.
    GRC_COM_NOT_GEOCOM = 3094  # Parse failed; data package not recognised as GeoCOM communication package
    GRC_COM_UNKNOWN_PORT = 3095  # Tried to access an unknown hardware port.
    GRC_COM_OVERRUN = 3100  # Overruns during receive.
    GRC_COM_SRVR_RX_CHECKSUM_ERROR = 3101  # Checksum received at server is wrong
    GRC_COM_CLNT_RX_CHECKSUM_ERROR = 3102  # Checksum received at client is wrong
    GRC_COM_PORT_NOT_AVAILABLE = 3103  # COM port not available
    GRC_COM_PORT_NOT_OPEN = 3104  # COM port not opened / initialised
    GRC_COM_NO_PARTNER = 3105  # No communications partner on other end.
    GRC_COM_ERO_NOT_STARTED = 3106
    GRC_COM_CONS_REQ = 3107  # Attention to send consecutive requests.
    GRC_COM_SRVR_IS_SLEEPING = 3108  # TPS has gone to sleep. Wait and try again.
    GRC_COM_SRVR_IS_OFF = 3109  # TPS has shut down. Wait and try again
    GRC_AUT_TIMEOUT = 8704  # Timeout while positioning of one or both axes.
    GRC_AUT_Detent_ERROR = 8705  # Positioning not possible due to mounted EDM.
    GRC_AUT_ANGLE_ERROR = 8706  # Angle measurement error
    GRC_AUT_MOTOR_ERROR = 8707  # Instrument has no ‘motorization’.
    GRC_AUT_INCACC = 8708  # Position not exactly reached
    GRC_AUT_DEV_ERROR = 8709  # During the determination of the angle deviation error detected
    GRC_AUT_NO_TARGET = 8710  # No target found
    GRC_AUT_MULTIPLE_TARGETS = 8711  # Multiple targets found.
    GRC_AUT_BAD_ENVIRONMENT = 8712  # Bad environment conditions.
    GRC_AUT_DETECTOR_ERROR = 8713  # Error in target acquisition.
    GRC_AUT_NOT_ENABLED = 8714  # ATR mode not enabled
    GRC_AUT_CALACC = 8715  # ATR-calibration failed
    GRC_AUT_ACCURACY = 8716  # Inexact fine position
    GRC_AUT_DIST_STARTED = 8717  # Info
    GRC_AUT_SUPPLY_TOO_HIGH = 8718  # external Supply voltage is too high
    GRC_AUT_SUPPLY_TOO_LOW = 8719  # int. or ext. Supply volatage is too low
    GRC_AUT_NO_WORKING_AREA = 8720  # Working area not defined
    GRC_AUT_ARRAY_FULL = 8721  # power search data array is filled
    GRC_AUT_NO_DATA = 8722  # no data available
    GRC_AUT_SIDECOVER_ERR = 8723  # motion cannot executed because of sidecover
    GRC_AUT_OUT_OF_SYNC = 8724  # angle requested for time not in collection (probably telescope out of sync)
    GRC_AUT_NO_LOCK = 8725  # lock mode not allowed
    GRC_KDM_NOT_AVAILABLE = 12544  # KDM device is not available
    GRC_FTR_FILEACESS = 13056  # File access error
    GRC_FTR_WRONGFILEBLOCKNUMBER = 13057  # block number was not the expected one
    GRC_FTR_NOTENOUGHSPACE = 13058  # not enough space on device to proceed uploading
    GRC_FTR_INVALIDINPUT = 13059  # rename of file failed
    GRC_FTR_MISSINGSETUP = 13060  # invalid parameter as input
